#### Please select the sections that you would like to print

Select All
Case Information
Party
Disposition Events
Events and Hearings
Financial
Print

# Case Information

17D27499 | OAKS AT STONECREST VS Kenny Hardison,ALL OTHER

Case Number
17D27499

Court
Division 0

Judicial Officer
Anderson, Berryl A

File Date
10/18/2017

Case Type
Magistrate Dispossessory - Non Payment of Rent

Case Status
Administratively Closed

# Party

Plaintiff
OAKS AT STONECREST

Active Attorneys

Lead Attorney
Murphy, Andrew T

Retained

Defendant
Hardison, Kenny

Address

2795 Evans Mill RD
UNIT 2503
Lithonia GA 30058

Active Attorneys

Pro Se

Defendant
ALL OTHER

Active Attorneys

Pro Se

# Disposition Events

12/12/2017 Judgment

Judicial Officer
Polk, Nora

Judgment Type
Writ Issued

# Events and Hearings

- 10/18/2017 Dispossessory Warrant

- 10/18/2017 Dispossessory Service

  Unserved

  Anticipated Server
  Private Process Servers

  Anticipated Method

  Unserved

  Anticipated Server
  Private Process Servers

  Anticipated Method

- 12/05/2017 Writ application sent to judge

- 12/06/2017 Judge's Directive

  Judicial Officer
  Polk, Nora

- 12/07/2017 Writ application sent to judge

- 12/13/2017 Writ To Marshal

- 12/13/2017 Writ Service

  Unserved

  Anticipated Server
  Marshal

  Anticipated Method

- 12/14/2017 Tenant Ejected

Loading financial, please wait...